@@ -235,7 +235,6 @@ class XSettingsOverrides:
     VARIANT_TYPES = {
         'Gtk/ShellShowsAppMenu': GLib.Variant.new_int32,
         'Gtk/EnablePrimaryPaste': GLib.Variant.new_int32,
-        'Gtk/DecorationLayout': GLib.Variant.new_string,
         'Gdk/WindowScalingFactor': GLib.Variant.new_int32,
     }
 
@@ -281,8 +280,6 @@ class XSettingsOverrides:
         self._set_override('Gtk/EnablePrimaryPaste', int(v))
     def get_enable_primary_paste(self):
         return self._get_override('Gtk/EnablePrimaryPaste', True)
-    def set_window_buttons(self, v):
-        self._set_override('Gtk/DecorationLayout', v)
     def set_window_scaling_factor(self, v):
         self._set_override('Gdk/WindowScalingFactor', int(v))
     def get_window_scaling_factor(self):
